@@ -14,7 +14,7 @@ use constant +{
     COMPRESS_SAVINGS => 0.20,
 };
 
-our $VERSION = '0.00017';
+our $VERSION = '0.00018';
 
 sub new {
     my $class = shift;
@@ -184,7 +184,7 @@ sub connect {
 
 sub add {
     my ($self, @args) = @_;
-    my $cb = pop @args if ref $args[-1] eq 'CODE';
+    my $cb = pop @args if (ref $args[-1] eq 'CODE' or ref $args[-1] eq 'AnyEvent::CondVar');
     my ($key, $value, $exptime, $noreply) = @args;
     $self->push_queue( 
         $self->protocol, 'add', $key, $value, $exptime, $noreply, $cb );
@@ -192,14 +192,14 @@ sub add {
 
 sub decr {
     my ($self, @args) = @_;
-    my $cb = pop @args if ref $args[-1] eq 'CODE';
+    my $cb = pop @args if (ref $args[-1] eq 'CODE' or ref $args[-1] eq 'AnyEvent::CondVar');
     my ($key, $value, $initial) = @args;
     $self->push_queue( $self->protocol, 'decr', $key, $value, $initial, $cb );
 }
 
 sub delete {
     my ($self, @args) = @_;
-    my $cb       = pop @args if ref $args[-1] eq 'CODE';
+    my $cb       = pop @args if (ref $args[-1] eq 'CODE' or ref $args[-1] eq 'AnyEvent::CondVar');
     my $noreply  = !defined $cb;
     $self->push_queue( $self->protocol, 'delete', @args, $noreply, $cb );
 }
@@ -218,40 +218,40 @@ sub get_multi {
 
 sub incr {
     my ($self, @args) = @_;
-    my $cb = pop @args if ref $args[-1] eq 'CODE';
+    my $cb = pop @args if (ref $args[-1] eq 'CODE' or ref $args[-1] eq 'AnyEvent::CondVar');
     my ($key, $value, $initial) = @args;
     $self->push_queue( $self->protocol, 'incr', $key, $value, $initial, $cb );
 }
 
 sub replace {
     my ($self, @args) = @_;
-    my $cb = pop @args if ref $args[-1] eq 'CODE';
+    my $cb = pop @args if (ref $args[-1] eq 'CODE' or ref $args[-1] eq 'AnyEvent::CondVar');
     my ($key, $value, $exptime, $noreply) = @args;
     $self->push_queue( $self->protocol, 'replace', $key, $value, $exptime, $noreply, $cb );
 }
 
 sub set {
     my ($self, @args) = @_;
-    my $cb = pop @args if ref $args[-1] eq 'CODE';
+    my $cb = pop @args if (ref $args[-1] eq 'CODE' or ref $args[-1] eq 'AnyEvent::CondVar');
     my ($key, $value, $exptime, $noreply) = @args;
     $self->push_queue( $self->protocol, 'set', $key, $value, $exptime, $noreply, $cb);
 }
 
 sub append {
     my ($self, @args) = @_;
-    my $cb = pop @args if ref $args[-1] eq 'CODE';
+    my $cb = pop @args if (ref $args[-1] eq 'CODE' or ref $args[-1] eq 'AnyEvent::CondVar');
     $self->push_queue( $self->protocol, 'append', @args, undef, undef, $cb);
 }
 
 sub prepend {
     my ($self, @args) = @_;
-    my $cb = pop @args if ref $args[-1] eq 'CODE';
+    my $cb = pop @args if (ref $args[-1] eq 'CODE' or ref $args[-1] eq 'AnyEvent::CondVar');
     $self->push_queue( $self->protocol, 'prepend', @args, undef, undef, $cb);
 }
 
 sub stats {
     my ($self, @args) = @_;
-    my $cb = pop @args if ref $args[-1] eq 'CODE';
+    my $cb = pop @args if (ref $args[-1] eq 'CODE' or ref $args[-1] eq 'AnyEvent::CondVar');
     my ($name) = @args;
     $self->push_queue( $self->protocol, 'stats', $name, $cb );
 }
@@ -261,6 +261,14 @@ sub version {
     $self->push_queue( $self->protocol, 'version', $cb);
 }
 
+sub flush_all {
+    my ($self, @args) = @_;
+    my $cb = pop @args if (ref $args[-1] eq 'CODE' or ref $args[-1] eq 'AnyEvent::CondVar');
+    my $noreply = !!$cb;
+    my $delay = shift @args || 0;
+    $self->push_queue( $self->protocol, 'flush_all', $delay, $noreply, $cb );
+}
+
 sub push_queue {
     my ($self, @args) = @_;
     push @{$self->{queue}}, [ @args ];
@@ -460,6 +468,21 @@ So choose according to your needs. If you for some reason don't want AnyEvent::C
 
 =head1 METHODS
 
+All methods interacting with a memcached server which can take a callback
+function can also take a condvar instead. For example, 
+
+    $memd->get( "foo", sub {
+        my $value = shift;
+    } );
+
+is equivalent to
+
+    my $cv = AE::cv {
+        my $value = $_[0]->recv;
+    };
+    $memd->get( "foo", $cv );
+    # optionally, call $cv->recv here.
+
 =head2 new(%args) 
 
 =over 4
@@ -494,7 +517,7 @@ C<%args> can also be a hashref.
 
 =head2 add($key, $value[, $exptime, $noreply], $cb->($rc))
 
-=head2 append($key, $value, $cb->($rc));
+=head2 append($key, $value, $cb->($rc))
 
 =head2 connect()
 
@@ -507,6 +530,8 @@ explicitly.
 
 =head2 disconnect()
 
+=head2 flush_all()
+
 =head2 get($key, $cb->($value))
 
 =head2 get_handle( $host_port )
